@@ -2,6 +2,7 @@
 
 /* 
  * Copyright (C) 2001 Havoc Pennington
+ * Copyright (C) 2005 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -42,7 +43,8 @@ typedef enum
   META_FRAME_MAXIMIZED                = 1 << 9,
   META_FRAME_ALLOWS_SHADE             = 1 << 10,
   META_FRAME_ALLOWS_MOVE              = 1 << 11,
-  META_FRAME_FULLSCREEN               = 1 << 12
+  META_FRAME_FULLSCREEN               = 1 << 12,
+  META_FRAME_IS_FLASHING              = 1 << 13
 } MetaFrameFlags;
 
 typedef enum
@@ -57,7 +59,14 @@ typedef enum
   META_MENU_OP_STICK       = 1 << 7,
   META_MENU_OP_WORKSPACES  = 1 << 8,
   META_MENU_OP_MOVE        = 1 << 9,
-  META_MENU_OP_RESIZE      = 1 << 10
+  META_MENU_OP_RESIZE      = 1 << 10,
+  META_MENU_OP_ABOVE       = 1 << 11,
+  META_MENU_OP_UNABOVE     = 1 << 12,
+  META_MENU_OP_MOVE_LEFT   = 1 << 13,
+  META_MENU_OP_MOVE_RIGHT  = 1 << 14,
+  META_MENU_OP_MOVE_UP     = 1 << 15,
+  META_MENU_OP_MOVE_DOWN   = 1 << 16,
+  META_MENU_OP_RECOVER     = 1 << 17
 } MetaMenuOp;
 
 typedef struct _MetaWindowMenu MetaWindowMenu;
@@ -65,6 +74,7 @@ typedef struct _MetaWindowMenu MetaWindowMenu;
 typedef void (* MetaWindowMenuFunc) (MetaWindowMenu *menu,
                                      Display        *xdisplay,
                                      Window          client_xwindow,
+				     Time	     timestamp,
                                      MetaMenuOp      op,
                                      int             workspace,
                                      gpointer        data);
@@ -117,7 +127,6 @@ typedef enum
   META_GRAB_OP_CLICKING_MENU
 } MetaGrabOp;
 
-
 typedef enum
 {
   META_CURSOR_DEFAULT,
@@ -128,7 +137,10 @@ typedef enum
   META_CURSOR_SE_RESIZE,
   META_CURSOR_SW_RESIZE,
   META_CURSOR_NE_RESIZE,
-  META_CURSOR_NW_RESIZE
+  META_CURSOR_NW_RESIZE,
+  META_CURSOR_MOVE_WINDOW,
+  META_CURSOR_RESIZE_WINDOW,
+  META_CURSOR_BUSY
 
 } MetaCursor;
 
@@ -139,6 +151,13 @@ typedef enum
   META_FOCUS_MODE_MOUSE
 } MetaFocusMode;
 
+typedef enum
+{
+  META_ACTION_DOUBLE_CLICK_TITLEBAR_TOGGLE_SHADE,
+  META_ACTION_DOUBLE_CLICK_TITLEBAR_TOGGLE_MAXIMIZE,
+  META_ACTION_DOUBLE_CLICK_TITLEBAR_LAST
+} MetaActionDoubleClickTitlebar;
+
 typedef enum
 {
   META_FRAME_TYPE_NORMAL,
@@ -167,6 +186,48 @@ typedef enum
   META_VIRTUAL_MOD5_MASK     = 1 << 14
 } MetaVirtualModifier;
 
+/* Relative directions or sides seem to come up all over the place... */
+/* FIXME: Replace
+ *   place.[ch]:MetaWindowEdgePosition,
+ *   screen.[ch]:MetaScreenDirection,
+ *   workspace.[ch]:MetaMotionDirection,
+ * with the use of MetaDirection.
+ */
+typedef enum
+{
+  META_DIRECTION_LEFT      = 1 << 0,
+  META_DIRECTION_RIGHT     = 1 << 1,
+  META_DIRECTION_TOP       = 1 << 2,
+  META_DIRECTION_BOTTOM    = 1 << 3,
+  META_DIRECTION_UP        = 1 << 2, /* Alternate name for TOP */
+  META_DIRECTION_DOWN      = 1 << 3  /* Alternate name for BOTTOM */
+} MetaDirection;
+
+/* Function a window button can have.  Note, you can't add stuff here
+ * without extending the theme format to draw a new function and
+ * breaking all existing themes.
+ */
+typedef enum
+{
+  META_BUTTON_FUNCTION_MENU,
+  META_BUTTON_FUNCTION_MINIMIZE,
+  META_BUTTON_FUNCTION_MAXIMIZE,
+  META_BUTTON_FUNCTION_CLOSE,
+  META_BUTTON_FUNCTION_LAST
+} MetaButtonFunction;
+
+#define MAX_BUTTONS_PER_CORNER META_BUTTON_FUNCTION_LAST
+
+typedef struct _MetaButtonLayout MetaButtonLayout;
+struct _MetaButtonLayout
+{
+  /* buttons in the group on the left side */
+  MetaButtonFunction left_buttons[MAX_BUTTONS_PER_CORNER];
+  
+  /* buttons in the group on the right side */
+  MetaButtonFunction right_buttons[MAX_BUTTONS_PER_CORNER];
+};
+
 /* should investigate changing these to whatever most apps use */
 #define META_ICON_WIDTH 32
 #define META_ICON_HEIGHT 32
@@ -183,7 +244,3 @@ typedef enum
   (ycoord) <  ((rect).y + (rect).height))
 
 #endif
-
-
-
-
